#ifndef _CAN0_H
#define _CAN0_H
/***********************************************************************************
FILE NAME  		can0.h
DESCRIPTION		This header file contains defines used for the can example code 					                

Copyright   : 2005 Renesas Technology Europe Ltd.
Copyright   : 2005 Renesas Technology Corporation.
All Rights Reserved

***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2005 RTE-NPS First Release
***********************************************************************************/

#define SENDING_DELAY	(100000UL)
#define POLLING_DELAY	(100000UL)

#define	NO_ERROR		(0)
#define	SLOT_ERROR		(1)
#define	LENGTH_ERROR	(2)
#define	TIMEOUT_ERROR	(3)

#define	TRANSMIT		(0)
#define	RECEIVE			(1)

/* In the sample application, Slot0/Mailbox0 transmits a Message ID 0  to
   Slot6/Mailbox6 with configured with same message ID 0 */

/* User needs to configure following Slot/Mailbox as TRANSMIT or RECEIVE state as required*/
#define	C0Slot00_STATE	TRANSMIT
#define	C0Slot01_STATE	RECEIVE
#define	C0Slot02_STATE	RECEIVE
#define	C0Slot03_STATE	RECEIVE
#define	C0Slot04_STATE	RECEIVE
#define	C0Slot05_STATE	RECEIVE
#define	C0Slot06_STATE	RECEIVE
#define	C0Slot07_STATE	RECEIVE
#define	C0Slot08_STATE	RECEIVE
#define	C0Slot09_STATE	RECEIVE
#define	C0Slot10_STATE	RECEIVE
#define	C0Slot11_STATE	RECEIVE
#define	C0Slot12_STATE	RECEIVE
#define	C0Slot13_STATE	RECEIVE
#define	C0Slot14_STATE	RECEIVE
#define	C0Slot15_STATE	RECEIVE

/* User needs to configure following message IDs here for specific Slot/Mailbox*/
#define	C0Slot0Id 		0x0000000L

#define	C0Slot1Id  		0x0000001L
#define	C0Slot2Id  		0x0000002L
#define	C0Slot3Id  		0x0000003L
#define	C0Slot4Id  		0x0000004L
#define	C0Slot5Id  		0x0000005L

#define	C0Slot6Id  		0x0000000L

#define	C0Slot7Id  		0x0000007L
#define	C0Slot8Id  		0x0000008L
#define	C0Slot9Id  		0x0000009L
#define	C0Slot10Id 		0x0000010L
#define	C0Slot11Id 		0x0000011L
#define	C0Slot12Id 		0x0000012L
#define	C0Slot13Id 		0x0000013L
#define	C0Slot14Id 		0x0000014L
#define	C0Slot15Id 		0x0000015L

/*	Default CAN Baud Rate Settings
	These values are for a SYSTEM CLOCK of 20MHz, (10MHz External Cystal x 2 PLL Circuit)

 		            BIT TIME
 		<------------------------------>
        | SS |  PTS  |  PBS1  |  PBS2  |

		SS (Synchronization Segment)		= 	1 Tq
		PTS (Propagation Time Segment)		= 	1 Tq to 8 Tq
		PBS1 (Phase Buffer Segment 1)		= 	2 Tq to 8 Tq
 		PBS2 (Phase Buffer Segment 2)		= 	2 Tq to 8 Tq
		SJW (Resynchronization Jump Width)	= 	1 Tq to 4 Tq

		1 bit time 	= SS + PTS + PBS1 + PBS2 
					= 8 to 25 Tq's

		PBS1 >= PBS2
		PBS1 >= SJW
		PBS2 >= 2 when SJW = 1
		PBS2 >= SJW when 2 <= SJW <= 4

	BAUD RATE 	=	fCANCLK
				  -----------
				  Tq in 1 bit

	where fCANCLK =         f1 
				  	-------------------- 
				    2 x fCAN x (BRP + 1) 


	where	f1 = M16C/6N4 operating frequency (System Clk)
			fCAN Division = 1 to 1/16, specified in CCLKR register
			P = BAUD RATE prescaler (0 to 15), specified in CiCONR Register
			Tq = Number of Time Quanta in 1 bit time
*/

#define CAN0_BAUD_1MBPS
/*#define CAN0_BAUD_500KBPS */
/*#define CAN0_BAUD_125KBPS */
/*#define CAN0_BAUD_100KBPS */

#ifdef CAN0_BAUD_1MBPS

	#define CAN0_CLOCK_DIVIDER			0	/* fCAN = 1 */
	#define	CAN0_BAUD_RATE_PRESCALER	0	/* (BRP + 1) = 1 */
	#define	CAN0_PROP_TIME_SEG			2	/* PTS  = 3 Tq */
	#define	CAN0_PHASE_BUFF_SEG1		2	/* PBS1 = 3 Tq */
	#define	CAN0_PHASE_BUFF_SEG2		2	/* PBS2 = 3 Tq */
	#define CAN0_RE_SYNC_JUNP_WIDTH		1	/* SJW  = 2 Tq */
	#define CAN0_SAMPLE_POINT			0	/* 1 sample point */

#elif CAN0_BAUD_500KBPS

	#define CAN0_CLOCK_DIVIDER			1	/* fCAN = 2	 */
	#define	CAN0_BAUD_RATE_PRESCALER	0	/* (BRP + 1) = 1 */
	#define	CAN0_PROP_TIME_SEG			2	/* PTS  = 3 Tq */
	#define	CAN0_PHASE_BUFF_SEG1		2	/* PBS1 = 3 Tq */
	#define	CAN0_PHASE_BUFF_SEG2		2	/* PBS2 = 3 Tq */
	#define CAN0_RE_SYNC_JUNP_WIDTH		1	/* SJW  = 2 Tq */
	#define CAN0_SAMPLE_POINT			0	/* 1 sample point */

#elif CAN0_BAUD_125KBPS

	#define CAN0_CLOCK_DIVIDER			1	/* fCAN = 2 */
	#define	CAN0_BAUD_RATE_PRESCALER	3	/* (BRP + 1) = 4 */
	#define CAN0_SAMPLE_POINT			0	/* 1 sample point */
	#define	CAN0_PROP_TIME_SEG			6	/* PTS  = 7 Tq */
	#define	CAN0_PHASE_BUFF_SEG1		5	/* PBS1 = 6 Tq */
	#define	CAN0_PHASE_BUFF_SEG2		5	/* PBS2 = 6 Tq */
	#define CAN0_RE_SYNC_JUNP_WIDTH		1	/* SJW  = 2 Tq */

#elif CAN0_BAUD_100KBPS

	#define CAN0_CLOCK_DIVIDER			1	/* fCAN = 2 */
	#define	CAN0_BAUD_RATE_PRESCALER	4	/* (BRP + 1) = 5 */
	#define CAN0_SAMPLE_POINT			0	/* 1 sample point */
	#define	CAN0_PROP_TIME_SEG			6	/* PTS  = 7 Tq */
	#define	CAN0_PHASE_BUFF_SEG1		5	/* PBS1 = 6 Tq */
	#define	CAN0_PHASE_BUFF_SEG2		5	/* PBS2 = 6 Tq */
	#define CAN0_RE_SYNC_JUNP_WIDTH		1	/* SJW  = 2 Tq */ 

#endif

/**********************************************************************************
Function Prototypes
**********************************************************************************/
void InitCAN0(void);
int WriteCAN0Message(unsigned char Slot, unsigned char Length, unsigned char *ptrData);
int SendCAN0Message(unsigned char Slot);
int Check_err_can01(void);
int PollCAN0Message(unsigned char Slot);
int ReadCAN0Message(unsigned char Slot, unsigned char* pRxDataBuff);


#endif
