/***********************************************************************************
FILE NAME  	: hwsetup.c
DESCRIPTION	: Hardware Setup functions

Copyright   : 2005 Renesas Technology Europe Ltd.
Copyright   : 2005 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
14.09.2005 RTE-DDE First Release
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/

/***********************************************************************************
User Includes
***********************************************************************************/
/* sfr29.h provides a structure to access all of the device registers. */
#include "sfr29.h"
/* RSKM16C29def.h provides common defines for widely used items. */
#include "rskM16C29def.h"
#include "hwsetup.h"
#include "interrupts.h"

/***********************************************************************************
User Program Code Prototypes
***********************************************************************************/
/* These functions are private so their prototypes are defined locally */
void ConfigureOperatingFrequency(void);
void EnablePeripheralModules(void);
void ConfigurePortPins(void);

/**********************************************************************************
Global variables
***********************************************************************************/

/***********************************************************************************
User Program Code 
***********************************************************************************/

/***********************************************************************************
Function Name : HardwareSetup
Description   :	Sets up hardware
Parameters    : none
Return value  : none
***********************************************************************************/
void HardwareSetup(void)
{    
	ConfigureOperatingFrequency();

	ConfigurePortPins();

	EnablePeripheralModules();

	ConfigureInterrupts();
}

/***********************************************************************************
End of function HardwareSetup
***********************************************************************************/

/***********************************************************************************
Function Name : ConfigureOperatingFrequency
Description   : Sets up operating speed
Parameters    : none
Return value  : none
***********************************************************************************/
void ConfigureOperatingFrequency(void)
{
	/* enable access to processor mode registers */
	prc1 = 1;
	/* 2 wait states for sfr access...this is the reset value
	necessary for >16Mhz operation, can be set to 1 wait for <=16Mhz */
	pm20 = 0;                       
    /* disable access to processor mode registers */                              
    prc1 = 0;                       
    /* configure and switch main clock to xtal at 20MHz */
 	/* enable access to clock registers */
    prc0 = 1;
	/* set to hi-drive Xin, divide by 1 */           
    cm1 = 0x20;
	/* set to main clock using divide by 1 */       
    cm0 = 0x08;
	/* switch to Xin */                     
    cm21 = 0;
	/* disable access to clock registers */                       
 	prc0 = 0;                      
 
}
/***********************************************************************************
End of function ConfigureOperatingFrequency
***********************************************************************************/

/***********************************************************************************
Function Name : ConfigurePortPins
Description   :	Configures port pins 
Parameters    : none
Return value  : none
***********************************************************************************/
void ConfigurePortPins(void)
{
/* Port pins default to inputs. To ensure safe initialisation set the pin states
before changing the data direction registers. This will avoid any unintentional
state changes on the external ports.
Many peripheral modules will override the setting of the port registers. Ensure
that the state is safe for external devices if the internal peripheral module is
disabled or powered down. */

/* General device configuration */
	/* Enables next instruction to set pacr */
	prcr = 0x04;
	/* Set to 80 pin chip */			
	pacr = 0x03;				

/* Switch Port configuration */
	/* All pins are inputs by default */

/* LED Port configuration */
	pd2 = 0xf0;

/* LCD Module Port configuration */
	/* Set control = outputs M16C allows reading of ddr)*/
	pd1 |= 0x90;
	/* Set data = outputs (M16C allows reading of ddr) */			
	pd1 |= 0x0f;			
}
/***********************************************************************************
End of function ConfigurePortPins
***********************************************************************************/

/***********************************************************************************
Function Name :	EnablePeripheralModules
Description	  :	Enables Peripheral Modules before use
Parameters	  : none
Return value  : none
***********************************************************************************/
void EnablePeripheralModules(void)
{
	/* All modules are active in the M16C device */
}
/***********************************************************************************
End of function EnablePeripheralModules
***********************************************************************************/

/***********************************************************************************
Function Name : ConfigureInterrupts
Description   :	Configure inteerrupt enables and settings
Parameters    : none
Return value  : none
***********************************************************************************/
void ConfigureInterrupts(void)
{
	/* Set interrupt priorities here if required */

	/* Required to set this to 0 before interrupt enable */
//	ifsr2a = 0x00;
	/* Enable interrupts by setting i flag */
//	asm("fset i");
}
/***********************************************************************************
End of function ConfigureInterrupts
***********************************************************************************/


