/***********************************************************************************
FILE NAME  	: main.c
DESCRIPTION	: Main Program

	  This example supports CAN 2.0B (29-bits Extended ID) protocol using POLLING mode for RSK-16C/29.
	  1. Connect two RSK-M16C/29 boards via 3-wire CAN connecting cable.
	  2. Slot / Message Box-0 is Transmitter and Slot / Message Box-6 is Receiver.
	     This configuration could be setup in "can0.h" file. 
	  3. Msg. ID = 0,  Data Lenght = 8, Data ="RENESAS\0"     

	  4. LEDs SIGNIFICANCE:
	     LED0- GREEN - ON, when CAN communication between both bords successful.
	     LED1- ORANGE- ON, There is a transmission error.
	     LED2- RED   - ON, There is a reception error.

Copyright   : 2005 Renesas Technology Europe Ltd.
Copyright   : 2005 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
07.07.2005 RTE-MAB First Release
***********************************************************************************/

/**********************************************************************************
System Includes
***********************************************************************************/
#include <string.h>

/**********************************************************************************
User Includes
***********************************************************************************/
/* sfr29.h provides common defines for widely used items. */
#include "sfr29.h"
/* rskm16c29defs.h provides common defines. */
#include "rskM16C29def.h"
#include "main.h"
#include "can0.h"

/**********************************************************************************
Global variables
***********************************************************************************/

/**********************************************************************************
User Program Code
***********************************************************************************/

/**********************************************************************************
Function Name: 	Main
Description  :	Main function
Parameters   : 	none
Return value : 	none
***********************************************************************************/
void main(void)				
{
	int iStatus = NO_ERROR;
	unsigned char TxDataBuff[8] = {"RENESAS"};
	unsigned char RxDataBuff[8];

	/* Turn LEDs 0-3 OFF */	
	LED_PORT_DR = LEDS_OFF;

	/* Initialize CAN */
	InitCAN0();

	/* Send continous message & receive messages */
	while(1)
	{
		do 
		{
			/* Setup write message for Slot / Message Box-0*/
			WriteCAN0Message(0, 8, TxDataBuff);

			/* Start message transmission */
			SendCAN0Message(0);

			/* Check for errors */
			iStatus = Check_err_can01();

			if(NO_ERROR != iStatus )
			{
				/* Orange LED ON*/
				LED_PORT_DR = 0xD0;  
				continue; /* Try again */
			}

			/* Poll message at Slot / Message Box-6*/
			iStatus = PollCAN0Message(6);

			if(NO_ERROR != iStatus )
			{
				/* Red LED ON*/
				LED_PORT_DR = 0x70;  
				continue; /* Try again */
			}

			if(NO_ERROR == iStatus )
			{
				/* Read message at Slot / Message Box-6*/
				iStatus = ReadCAN0Message(6, RxDataBuff);
				if( 0 != strcmp(TxDataBuff, RxDataBuff) )
				{
					/* Red LED ON*/
					LED_PORT_DR = 0x70;  
					continue; /* Try again */
				}
			}

		} while(NO_ERROR != iStatus);

		/* Green LED ON*/
		LED_PORT_DR = 0xE0; 

	}

/* End of the user program. This function must not exit. */
	for(;;);
}         
/**********************************************************************************
End of function main
***********************************************************************************/   
